@@ -1,4 +1,8 @@
 fn main() {
+    if std::env::var("DOCS_RS").is_ok() {
+        return
+    }
+
     env_logger::init();
 
     let brew_lib_path = "/opt/homebrew/lib";
